pub struct MockApi;Trait Implementations
Sourceimpl KeycloakApi for MockApi
impl KeycloakApi for MockApi
Sourcefn search_users_by_username<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_search_params: &'life1 UserSearchParameters,
_pagination: &'life2 PageParameters,
_client: &'life3 Client,
) -> Pin<Box<dyn Future<Output = Result<Vec<UserDto>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
fn search_users_by_username<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
_search_params: &'life1 UserSearchParameters,
_pagination: &'life2 PageParameters,
_client: &'life3 Client,
) -> Pin<Box<dyn Future<Output = Result<Vec<UserDto>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Search for users by their username. Read more
Sourcefn get_users_by_ids<'life0, 'life1, 'async_trait>(
&'life0 self,
_client: &'life1 Client,
_user_ids: Vec<Uuid>,
) -> Pin<Box<dyn Future<Output = Result<Vec<UserDto>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_users_by_ids<'life0, 'life1, 'async_trait>(
&'life0 self,
_client: &'life1 Client,
_user_ids: Vec<Uuid>,
) -> Pin<Box<dyn Future<Output = Result<Vec<UserDto>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Gets all users given their ids from the Keycloak API. Read more
Sourcefn get_user_by_id<'life0, 'life1, 'async_trait>(
&'life0 self,
_client: &'life1 Client,
user_id: Uuid,
) -> Pin<Box<dyn Future<Output = Result<UserDto>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_user_by_id<'life0, 'life1, 'async_trait>(
&'life0 self,
_client: &'life1 Client,
user_id: Uuid,
) -> Pin<Box<dyn Future<Output = Result<UserDto>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Gets a user by its id from the Keycloak API. Read more