pub struct AreaDto {
pub id: Uuid,
pub layer_id: Uuid,
pub area_type: AreaType,
pub geometry: Polygon<Point>,
pub add_date: Option<NaiveDate>,
pub remove_date: Option<NaiveDate>,
pub notes: String,
}Expand description
Represents area on a map. Areas are for “brushing layers”.
Fields
id: UuidThe id of the area.
layer_id: UuidThe layer the area is on.
area_type: AreaTypeThe type/strength of area.
geometry: Polygon<Point>The position of the area on the map.
E.g. {"rings": [[{"x": 0.0,"y": 0.0},{"x": 1000.0,"y": 0.0},{"x": 1000.0,"y": 1000.0},{"x": 0.0,"y": 1000.0},{"x": 0.0,"y": 0.0}]],"srid": 4326}
add_date: Option<NaiveDate>The date the area was added to the map. If None, the area has always existed.
remove_date: Option<NaiveDate>The date the area was removed from the map. If None, the area is still on the map.
notes: StringMarkdown notes.