pub struct MovePlantingDto {
pub id: Uuid,
pub x: i32,
pub y: i32,
}Expand description
Used to move an existing planting.
Fields
id: UuidThe id of the planting.
x: i32The x coordinate of the position on the map.
y: i32The y coordinate of the position on the map.