pub struct UpdateRemoveDatePlantingDto {
pub id: Uuid,
pub remove_date: Option<NaiveDate>,
}Expand description
Used to change the remove_date of a planting.
Fields
id: UuidThe id of the planting.
remove_date: Option<NaiveDate>The date the planting was removed from the map. If None, the planting is still on the map.