pub struct FindAreaParameters {
pub area_kind: AreaKind,
pub layer_id: Option<Uuid>,
pub from: NaiveDate,
pub to: NaiveDate,
}Expand description
Arguments for the database layer find shadings function.
Fields
area_kind: AreaKindType of area
layer_id: Option<Uuid>The id of the layer to find shadings for.
from: NaiveDateFirst date in the time frame shadings are searched for.
to: NaiveDateLast date in the time frame shadings are searched for.