pub struct NewGuidedTourProgress {
pub user_id: Uuid,
pub step_key: String,
}Expand description
Insertable for guided_tour_progress (completed_at uses DB default).
Fields
user_id: UuidID of the user who is completing the step
step_key: StringHuman readable id of the step the user is completing